vsutillib.xml package
=====================

The ``XmlDB`` class
-------------------

.. autoclass:: vsutillib.vsxml.XmlDB
    :members:

The ``xmlPrettyPrint`` function

.. autofunction:: vsutillib.vsxml.xmlPrettyPrint
